# ecfdataimport.py
# Copyright 2013 Roger Marsh
# Licence: See LICENCE (BSD licence)

"""Extract player and club data from ECF reference files.

The algorithms implemented by the imported functions are used with special
versions of _coerce_to_utf8, _strify, and _utf8ify.

"""

from ..basecore import ecfdataimport


def _strify(value):
    """Tranform a value from an ECF file to str.

    Assume iso-8859-1 encoding for value.

    """
    return value.decode('iso-8859-1')


def _utf8ify(value):
    """Tranform a value from an ECF file to utf-8 encoding."""
    return _strify(value).encode('utf8')


def _coerce_to_utf8(value):
    """Tranform a str value to utf-8 encoding."""
    if not isinstance(value, bytes):
        return value.encode('utf8')
    else:
        return value


def copy_ecf_clubs_post_1998_rules(
    results,
    logwidget=None,
    ecffile=None,
    ecfdate=None,
    parent=None,
    datecontrol=None,
    strify=_strify,
    utf8ify=_utf8ify,
    coerce_to_utf8=_coerce_to_utf8,
    **kwargs
    ):
    """"""
    return ecfdataimport.copy_ecf_clubs_post_1998_rules(
        results,
        logwidget=logwidget,
        ecffile=ecffile,
        ecfdate=ecfdate,
        parent=parent,
        datecontrol=datecontrol,
        strify=strify,
        utf8ify=utf8ify,
        coerce_to_utf8=coerce_to_utf8,
        **kwargs)


def copy_ecf_players_post_2011_rules(
    results,
    logwidget=None,
    ecffile=None,
    ecfdate=None,
    parent=None,
    datecontrol=None,
    strify=_strify,
    utf8ify=_utf8ify,
    coerce_to_utf8=_coerce_to_utf8,
    **kwargs
    ):
    """"""
    return ecfdataimport.copy_ecf_players_post_2011_rules(
        results,
        logwidget=logwidget,
        ecffile=ecffile,
        ecfdate=ecfdate,
        parent=parent,
        datecontrol=datecontrol,
        strify=strify,
        utf8ify=utf8ify,
        coerce_to_utf8=coerce_to_utf8,
        **kwargs)


def copy_ecf_players_post_1998_rules(
    results,
    logwidget=None,
    ecffile=None,
    ecfdate=None,
    parent=None,
    datecontrol=None,
    strify=_strify,
    utf8ify=_utf8ify,
    coerce_to_utf8=_coerce_to_utf8,
    **kwargs
    ):
    """"""
    return ecfdataimport.copy_ecf_players_post_1998_rules(
        results,
        logwidget=logwidget,
        ecffile=ecffile,
        ecfdate=ecfdate,
        parent=parent,
        datecontrol=datecontrol,
        strify=strify,
        utf8ify=utf8ify,
        coerce_to_utf8=coerce_to_utf8,
        **kwargs)


def copy_ecf_clubs_post_2011_rules(
    results,
    logwidget=None,
    ecffile=None,
    ecfdate=None,
    parent=None,
    datecontrol=None,
    strify=_strify,
    utf8ify=_utf8ify,
    coerce_to_utf8=_coerce_to_utf8,
    keyconvert=_utf8ify,
    datekey=_coerce_to_utf8,
    **kwargs
    ):
    """"""
    return ecfdataimport.copy_ecf_clubs_post_2011_rules(
        results,
        logwidget=logwidget,
        ecffile=ecffile,
        ecfdate=ecfdate,
        parent=parent,
        datecontrol=datecontrol,
        strify=strify,
        utf8ify=utf8ify,
        coerce_to_utf8=coerce_to_utf8,
        keyconvert=keyconvert,
        datekey=datekey,
        **kwargs)


def update_ecf_clubs_post_2006_rules(
    results,
    logwidget=None,
    ecffile=None,
    ecfdate=None,
    parent=None,
    datecontrol=None,
    strify=_strify,
    utf8ify=_utf8ify,
    coerce_to_utf8=_coerce_to_utf8,
    **kwargs
    ):
    """"""
    return ecfdataimport.update_ecf_clubs_post_2006_rules(
        results,
        logwidget=logwidget,
        ecffile=ecffile,
        ecfdate=ecfdate,
        parent=parent,
        datecontrol=datecontrol,
        strify=strify,
        utf8ify=utf8ify,
        coerce_to_utf8=coerce_to_utf8,
        **kwargs)


def update_ecf_players_post_2006_rules(
    results,
    logwidget=None,
    ecffile=None,
    ecfdate=None,
    parent=None,
    datecontrol=None,
    strify=_strify,
    utf8ify=_utf8ify,
    coerce_to_utf8=_coerce_to_utf8,
    **kwargs
    ):
    """"""
    return ecfdataimport.update_ecf_players_post_2006_rules(
        results,
        logwidget=logwidget,
        ecffile=ecffile,
        ecfdate=ecfdate,
        parent=parent,
        datecontrol=datecontrol,
        strify=strify,
        utf8ify=utf8ify,
        coerce_to_utf8=coerce_to_utf8,
        **kwargs)


def update_ecf_clubs_post_2011_rules(
    results,
    logwidget=None,
    ecffile=None,
    ecfdate=None,
    parent=None,
    datecontrol=None,
    strify=_strify,
    utf8ify=_utf8ify,
    coerce_to_utf8=_coerce_to_utf8,
    **kwargs
    ):
    """"""
    return ecfdataimport.update_ecf_clubs_post_2011_rules(
        results,
        logwidget=logwidget,
        ecffile=ecffile,
        ecfdate=ecfdate,
        parent=parent,
        datecontrol=datecontrol,
        strify=strify,
        utf8ify=utf8ify,
        coerce_to_utf8=coerce_to_utf8,
        **kwargs)


def update_ecf_players_post_2011_rules(
    results,
    logwidget=None,
    ecffile=None,
    ecfdate=None,
    parent=None,
    datecontrol=None,
    strify=_strify,
    utf8ify=_utf8ify,
    coerce_to_utf8=_coerce_to_utf8,
    **kwargs
    ):
    """"""
    return ecfdataimport.update_ecf_players_post_2011_rules(
        results,
        logwidget=logwidget,
        ecffile=ecffile,
        ecfdate=ecfdate,
        parent=parent,
        datecontrol=datecontrol,
        strify=strify,
        utf8ify=utf8ify,
        coerce_to_utf8=coerce_to_utf8,
        **kwargs)
