# knownnames.py
# Copyright 2017 Roger Marsh
# Licence: See LICENCE (BSD licence)

"""bsddb3 interface to results database for player names known in other
editions of event.
"""

from dptdb import dptapi

from gridsup.dpt.dptdatasource import DPTDataSource

from ..basecore.playerfind import find_player_names_in_other_editions_of_event


class KnownNamesDS(DPTDataSource):
    
    """Combine player names known in other editions of event with bsddb3
    interface.
    """

    def __init__(self, *a, **k):
        """Extend to provide placeholder for position used to select games.
        """
        super().__init__(*a, **k)
        
        # Event used to select player names in other editions of event.
        self.event = None

        # Map alias record for name, in other event editions, to person record.
        self.map_newplayer_to_knownplayer = {}

    def get_known_names(self, event):
        """Find records with same player name in other editions of event and
        put them on the recordset for display.
        """
        db = self.dbhome.get_database(self.dbset, self.dbname)
        dbi = self.dbhome.get_database_instance(self.dbset, self.dbname)
        recordset = db.CreateRecordList()
        if event:
            map_np_to_kp = find_player_names_in_other_editions_of_event(
                self.dbhome, event)
            for alias_recno in map_np_to_kp:
                recordset.Place(dbi.foundset_record_number(alias_recno))
        else:
            map_np_to_kp = {}
        self.set_recordset(recordset)
        self.event = event
        self.map_newplayer_to_knownplayer = map_np_to_kp

    def remove_record_from_recordset(self, record_number):
        """Remove record_number from self.recordset.

        Method exists for compatibility with non-DPT databases.
        """
        self.recordset.Remove(self.dbhome.get_database_instance(
            self.dbset, self.dbname).foundset_record_number(record_number))
